pub struct QueryFactory {}Expand description
A factory for creating child QueryBuilders inside a
QueryBuilder::then closure.
You never construct this directly; it is provided as the argument to
the closure passed to .then().
Implementations
Sourceimpl<'query> QueryFactory
impl<'query> QueryFactory
Sourcepub fn all(&self, query: &'query str, save: Save) -> QueryBuilder<'query>
pub fn all(&self, query: &'query str, save: Save) -> QueryBuilder<'query>
Create a child query that matches all occurrences of the selector.
Sourcepub fn first(&self, query: &'query str, save: Save) -> QueryBuilder<'query>
pub fn first(&self, query: &'query str, save: Save) -> QueryBuilder<'query>
Create a child query that matches only the first occurrence.